Get information about processes using mainly the pid
Get basic information about processes by PID
Structs
- List
Threads - Struct for List of Threads
Enums
- PidInfo
- The
PidInfoenum contains a piece of information about a processes - PidInfo
Flavor - An enum used to specify what type of information about a process is referenced See http://opensource.apple.com/source/xnu/xnu-1504.7.4/bsd/kern/proc_info.c
- Proc
Type - The
ProcTypetype. Used to specify what type of processes you are interested in in other calls, such aslistpids.
Traits
- ListPID
Info - The
ListPIDInfotrait is needed for polymorphism on listpidinfo types, also abstracting flavor in order to provide type-guaranteed flavor correctness - PIDInfo
- The
PIDInfotrait is needed for polymorphism on pidinfo types, also abstracting flavor in order to provide type-guaranteed flavor correctness
Functions
- am_root
- Return true if the calling process is being run by the root user, false otherwise
- cwdself
- Gets path of current working directory for the current process.
- libversion
- listpids
Deprecated - Returns the PIDs of the active processes that match the
proc_typesparameter - name
- Get the name of a process, using it’s process id (pid)
- pidcwd
- Gets the path of current working directory for the process with the provided pid.
- pidpath
- Get the path of the executable file being run for a process
- regionfilename